list

package
v0.3.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 1, 2026 License: Apache-2.0 Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewCommand

func NewCommand(log *logger.FunLogger) *cli.Command

NewCommand constructs the list command with the specified logger

Types

type ClusterInfo added in v0.3.0

type ClusterInfo struct {
	Region               string `json:"region,omitempty" yaml:"region,omitempty"`
	ControlPlaneCount    int32  `json:"controlPlaneCount,omitempty" yaml:"controlPlaneCount,omitempty"`
	WorkerCount          int32  `json:"workerCount,omitempty" yaml:"workerCount,omitempty"`
	TotalNodes           int32  `json:"totalNodes,omitempty" yaml:"totalNodes,omitempty"`
	ReadyNodes           int32  `json:"readyNodes,omitempty" yaml:"readyNodes,omitempty"`
	ControlPlaneEndpoint string `json:"controlPlaneEndpoint,omitempty" yaml:"controlPlaneEndpoint,omitempty"`
	HAEnabled            bool   `json:"haEnabled,omitempty" yaml:"haEnabled,omitempty"`
}

ClusterInfo represents cluster-specific information

type InstanceList added in v0.3.0

type InstanceList struct {
	Instances []InstanceOutput `json:"instances" yaml:"instances"`
}

InstanceList represents a list of instances for output formatting

func (*InstanceList) Headers added in v0.3.0

func (l *InstanceList) Headers() []string

Headers implements output.TableData

func (*InstanceList) Rows added in v0.3.0

func (l *InstanceList) Rows() [][]string

Rows implements output.TableData

type InstanceOutput added in v0.3.0

type InstanceOutput struct {
	ID          string       `json:"id" yaml:"id"`
	Name        string       `json:"name" yaml:"name"`
	Provider    string       `json:"provider" yaml:"provider"`
	Type        string       `json:"type" yaml:"type"`
	Nodes       string       `json:"nodes" yaml:"nodes"`
	Status      string       `json:"status" yaml:"status"`
	Provisioned bool         `json:"provisioned" yaml:"provisioned"`
	Age         string       `json:"age" yaml:"age"`
	CreatedAt   time.Time    `json:"createdAt" yaml:"createdAt"`
	Cluster     *ClusterInfo `json:"cluster,omitempty" yaml:"cluster,omitempty"`
}

InstanceOutput represents instance data for JSON/YAML output

Jump to