Documentation
¶
Index ¶
- Constants
- type ClusterInfo
- type Instance
- type Manager
- func (m *Manager) DeleteInstance(instanceID string) error
- func (m *Manager) GenerateInstanceID() (string, error)
- func (m *Manager) GetInstance(instanceID string) (*Instance, error)
- func (m *Manager) GetInstanceByFilename(filename string) (*Instance, error)
- func (m *Manager) GetInstanceCacheFile(instanceID string) (string, error)
- func (m *Manager) ListInstances() ([]Instance, error)
Constants ¶
const ( // InstanceLabelKey is the key used to label AWS instances InstanceLabelKey = "holodeck-instance-id" // InstanceProvisionedLabelKey is the key used to label AWS instances with their provisioning status InstanceProvisionedLabelKey = "holodeck-instance-provisioned" )
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ClusterInfo ¶ added in v0.3.0
type ClusterInfo struct {
Region string
ControlPlaneCount int32
WorkerCount int32
TotalNodes int32
ReadyNodes int32
ControlPlaneEndpoint string
HAEnabled bool
}
ClusterInfo holds summary information about a multinode cluster
type Instance ¶
type Instance struct {
ID string
Name string
Provider v1alpha1.Provider
CreatedAt time.Time
Status string
CacheFile string
Provisioned bool
// Cluster information (nil for single-node)
IsCluster bool
ClusterInfo *ClusterInfo
}
Instance represents a running Holodeck instance
type Manager ¶
type Manager struct {
// contains filtered or unexported fields
}
Manager handles instance operations
func NewManager ¶
NewManager creates a new instance manager
func (*Manager) DeleteInstance ¶
DeleteInstance removes an instance
func (*Manager) GenerateInstanceID ¶
GenerateInstanceID creates a unique ID for a new instance
func (*Manager) GetInstance ¶
GetInstance returns details for a specific instance
func (*Manager) GetInstanceByFilename ¶
GetInstanceByFilename returns details for a specific instance by its filename
func (*Manager) GetInstanceCacheFile ¶
GetInstanceCacheFile returns the cache file path for an instance. It validates that the instance ID matches expected formats to prevent path traversal.
func (*Manager) ListInstances ¶
ListInstances returns all running instances
Click to show internal directories.
Click to hide internal directories.