Documentation
¶
Index ¶
- func ExpandPath(path string) (string, error)
- func GetIPAddress() (string, error)
- func GetIPAddressWithServices(services []IPService) (string, error)
- func GetKubeConfig(log *logger.FunLogger, cfg *v1alpha1.Environment, hostUrl string, dest string, ...) error
- func RewriteKubeConfigServer(path string, serverURL string) error
- type IPService
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ExpandPath ¶ added in v0.3.0
ExpandPath expands a leading ~ to the user's home directory. Non-tilde paths are returned unchanged.
func GetIPAddress ¶ added in v0.2.14
GetIPAddress gets the IP address of the user with timeout and fallback services
func GetIPAddressWithServices ¶ added in v0.3.0
GetIPAddressWithServices gets the IP address using the provided list of services. This allows for testing with mock services.
func GetKubeConfig ¶
func GetKubeConfig(log *logger.FunLogger, cfg *v1alpha1.Environment, hostUrl string, dest string, desiredServerURL string) error
GetKubeConfig downloads the kubeconfig file from the remote host
func RewriteKubeConfigServer ¶ added in v0.3.0
RewriteKubeConfigServer rewrites the server URL in a kubeconfig file. If serverURL is empty, this is a no-op.
Types ¶
Click to show internal directories.
Click to hide internal directories.